==> fluidsynth_2.1.0.orig.tar.gz: fluidsynth-2.1.0/.github/issue_template.md <==
_This issue tracker is only for bug reports and concrete feature requests.
DO NOT SUBMIT SUPPORT REQUESTS OR "HOW TO" QUESTIONS HERE!
Else it might be closed without further notice._

_If you have a question look into our wiki
( https://github.com/FluidSynth/fluidsynth/wiki )
or the developer resources
( http://www.fluidsynth.org/api/ )_

_If you still have a question, need support or want to discuss ideas, contact our mailing list:
https://lists.nongnu.org/mailman/listinfo/fluid-dev_

_Below is a form that shall help getting relevant information for bugs and feature requests together.
We strongly recommend to use it! Feel free to edit or remove inapplicable/unneeded parts._

### FluidSynth version <!-- enter FluidSynths version you're using -->
2.0.x

### Current behavior
<!-- Describe the current situation, e.g. how the bug manifests. -->

### Expected behavior
<!-- Describe what the behavior would be without the bug or how the
     feature request would make your life easier. -->

### Steps to reproduce
<!--  Please explain the steps required to duplicate the issue,
      esp. if you are able to provide a sample application.
      E.g. how to start fluidsynth, what shell commands to enter, what midi events to send, etc. -->

### Other information
<!-- If you are able to illustrate the bug or feature request with an example, please provide simple
source code below or as attatched file. List any other information that is relevant to your issue:
  Stack traces,
  related issues,
  build logs,
  suggestions on how to fix,
  links to related discussions at fluid-dev
  etc. 
-->

==> fluidsynth_2.1.7.orig.tar.gz: fluidsynth-2.1.7/.github/issue_template.md <==
_This issue tracker is only for bug reports and concrete feature requests.
DO NOT SUBMIT SUPPORT REQUESTS OR "HOW TO" QUESTIONS HERE!
Else it might be closed without further notice._

_If you have a question look into our wiki
( https://github.com/FluidSynth/fluidsynth/wiki )
or the developer resources
( http://www.fluidsynth.org/api/ )_

_If you still have a question, need support or want to discuss ideas, contact our mailing list:
https://lists.nongnu.org/mailman/listinfo/fluid-dev_

_Below is a form that shall help getting relevant information for bugs and feature requests together.
We strongly recommend to use it! Feel free to edit or remove inapplicable/unneeded parts._

### FluidSynth version <!-- enter FluidSynths version you're using -->
2.0.x

### Current behavior
<!-- Describe the current situation, e.g. how the bug manifests. -->

### Expected behavior
<!-- Describe what the behavior would be without the bug or how the
     feature request would make your life easier. -->

### Steps to reproduce
<!--  Please explain the steps required to duplicate the issue,
      esp. if you are able to provide a sample application.
      E.g. how to start fluidsynth, what shell commands to enter, what midi events to send, etc. -->

### Other information
<!-- If you are able to illustrate the bug or feature request with an example, please provide simple
source code below or as attached file. List any other information that is relevant to your issue:
  Stack traces,
  related issues,
  build logs,
  suggestions on how to fix,
  links to related discussions at fluid-dev
  etc. 
-->
